@@ -4,7 +4,7 @@ from os import path
 from .client import Client
 
 name = "remarkable-cli"
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 __all__ = ["main"]
 
 
@@ -24,7 +24,7 @@ def main():
         dest="log_level",
         action="count",
         help="logging verbosity level",
-        default=3,
+        default=None,
     )
     parser.add_argument(
         "-a",
